Summary:	common error codes for GnuPG related projects
Name:		libgpg-error
Version:	1.51
Release:	1%{?_dist_release}
URL:		https://www.gnupg.org/related_software/libgpg-error/index.html
Source0:	ftp://ftp.gnupg.org/gcrypt/libgpg-error/%{name}-%{version}.tar.bz2
Source1:	ftp://ftp.gnupg.org/gcrypt/libgpg-error/%{name}-%{version}.tar.bz2.sig
Patch0:		%{name}-1.51-macos14.patch
Group:		System Environment/Libraries
License:	LGPL
BuildRoot:	%{_tmppath}/%{name}-%{version}-root

BuildArch:      fat
Vendor:		OSX WorkShop
Distribution:	OSX WorkShop

%description
This is a library that defines common error values for all GnuPG
components. Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
pinentry, SmartCard Daemon and possibly more in the future.

%package devel
Summary:	Development files for the %{name} package
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
This is a library that defines common error values for all GnuPG
components.  Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
pinentry, SmartCard Daemon and possibly more in the future. This package
contains files necessary to develop applications using libgpg-error.

%prep
%setup -q -c %{name}-%{version}
mv %{name}-%{version} ARM64
pushd ARM64
%patch0 -p1 -b .macos14
cp -f  AUTHORS README INSTALL NEWS ChangeLog ..
cp -f  COPYING COPYING.LIB ..
popd
cp -a ARM64 X86_64

%build
pushd ARM64
export CFLAGS="-O3 -arch arm64 -I%{_includedir}"
export CPPFLAGS="-arch arm64 -I%{_includedir}"
export CXXFLAGS="$CFLAGS"
export FFLAGS="$CFLAGS"
export FCFLAGS="$CFLAGS"
export LDFLAGS="-arch arm64 -L%{_libdir}"
export CC=clang
export CC_FOR_BUILD=clang
export CXX=clang++

%configure \
        --host=%{_rpm_platform_arm64} \
        --build=%{_rpm_platform_arm64} \
        --target=%{_rpm_platform_arm64} \
	--enable-install-gpg-error-config \
        --disable-static AWK=gawk

make %{?_smp_mflags}
popd

pushd X86_64
export CFLAGS="-O3 -arch x86_64 -I%{_includedir}"
export CPPFLAGS="-arch x86_64 -I%{_includedir}"
export CXXFLAGS="$CFLAGS"
export FFLAGS="$CFLAGS"
export FCFLAGS="$CFLAGS"
export LDFLAGS="-arch x86_64 -L%{_libdir}"
export CC=clang
export CC_FOR_BUILD=clang
export CXX=clang++

%configure \
        --host=%{_rpm_platform_x86_64} \
        --build=%{_rpm_platform_arm64} \
        --target=%{_rpm_platform_x86_64} \
        --disable-static AWK=gawk

make %{?_smp_mflags}
popd

%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf $RPM_BUILD_ROOT
PWD=`pwd`
pushd ARM64
rm -rf ${PWD}-root
mkdir -p ${PWD}-root
make install DESTDIR=${PWD}-root
popd

pushd X86_64
rm -rf ${PWD}-root
mkdir -p ${PWD}-root
make install DESTDIR=${PWD}-root
popd

## Make Universal Binaries
filelist=$(find ./ARM64-root -type f | xargs file | sed -e 's,^\./ARM64-root/,,g' | \
        grep -E \(Mach-O\)\|\(ar\ archive\) |sed -e 's,:.*,,g' -e '/\for\ architecture/d')

for i in $filelist
do
        /usr/bin/lipo -create ARM64-root/$i X86_64-root/$i -output `basename $i` && \
        (cp -f `basename $i` ARM64-root/$i) || :
done

# check header files
for i in `find ARM64-root -name "*.h" -type f`
do
        TARGET=`echo $i | sed -e "s,.*ARM64-root,,"`
        TEMP=`diff -u ARM64-root/$TARGET X86_64-root/$TARGET > /dev/null || echo different`
        if [ -n "$TEMP" ]; then
                mv X86_64-root/$TARGET ARM64-root/${TARGET%.*}-x86_64.h
                mv ARM64-root/$TARGET ARM64-root/${TARGET%.*}-arm64.h
                FILE=${TARGET##*/}
                FILE=${FILE%.*}
cat <<EOF > ARM64-root/$TARGET
#if defined (__arm64__)
#include "${FILE}-arm64.h"
#elif defined( __x86_64__ )
#include "${FILE}-x86_64.h"
#endif
EOF
        fi
done

# fix gpg-error-config
pushd ARM64-root/opt/osxws/bin
mv gpg-error-config gpg-error-config.orig
sed -e 's;aarch64;$(uname -m);g' gpg-error-config.orig > gpg-error-config
chmod 755 gpg-error-config
rm -f gpg-error-config.orig
popd

# install
mkdir -p %{buildroot}
tar cf - -C ARM64-root . | tar xpf - -C %{buildroot}


# remove unneeded files
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -rf $RPM_BUILD_ROOT%{_datadir}/common-lisp
rm -f $RPM_BUILD_ROOT%{_infodir}/dir

%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT


%post devel 
install-info %{_infodir}/gpgrt.info %{_infodir}/dir &>/dev/null || :

%preun devel 
if [ $1 -eq 0 ]; then
  install-info --delete %{_infodir}/gpgrt.info %{_infodir}/dir &>/dev/null || :
fi

%files -f %{name}.lang
%defattr(-,root,wheel)
%license COPYING COPYING.LIB
%doc AUTHORS README INSTALL NEWS ChangeLog
%{_bindir}/gpg-error
%{_libdir}/libgpg-error.*.dylib
%dir %{_datadir}/libgpg-error
%{_datadir}/libgpg-error/errorref.txt

%files devel
%defattr(-,root,wheel)
%{_bindir}/gpg-error-config
%{_bindir}/gpgrt-config
%{_bindir}/yat2m
%{_libdir}/libgpg-error.dylib
%{_libdir}/pkgconfig/gpg-error.pc
%{_includedir}/gpg-error*.h
%{_includedir}/gpgrt*.h
%{_datadir}/aclocal/gpg-error.m4
%{_datadir}/aclocal/gpgrt.m4
%{_infodir}/gpgrt.info*
%{_mandir}/man1/gpgrt-config.1*

%changelog
* Wed Dec 4 2024 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.51-1
- replaced macos13 patch by that for macos14
- OSXWS 14 fat

* Thu Oct 26 2023 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.47-1
- OSXWS 13 fat

* Sat Feb 26 2022 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.42-1
- OSXWS 12 fat

* Sun Apr 25 2021 KOBAYASHI Taizo <tkoba965@mac.com> - 1.42-1
- new upstream release
- OSXWS 11 fat

* Mon Jan 13 2020 KOBAYASHI Taizo <tkoba965@mac.com> - 1.36-1
- modified for OSXWS

* Sun May 05 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.36-1
- updated to 1.36.

* Thu Mar 01 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.27-1
- updated to 1.27.

* Mon Mar 20 2017 IWAI, Masaharu <iwaim.sub@gmail.com> 1.26-1
- update to 1.26
- add errorref.txt
- update URL tag
- add Packager tag

* Sat May 21 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.22-1
- new upstream release

* Mon Dec 30 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.12-1
- new upstream release

* Mon Apr  4 2011 IWAI, Masaharu <iwai@alib.jp> 1.10-1
- new upstream release

* Sat Oct 02 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.9-1
- new upstream release

* Thu Apr 29 2010 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.7-1
- new upstream release
- added --disable-static to %%configure
- built with new toolchain

* Sat Jun 27 2009 NAKAMURA Kenta <kenta@vinelinux.org> 1.6-3
- added compat32 package for x86_64 arch support

* Tue Mar 31 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.6-2
- spec in utf-8
- remove static lib

* Tue Mar 18 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.6-1vl5
- new upstream release
- used _dist_release macro

* Fri Mar 09 2007 KAZUKI SHIMURA <kazuki@ma.ccnw.ne.jp> 1.4-0vl1
- new upstream release
- add Vendor/Distribution tag

* Sun Apr 09 2006 KAZUKI SHIMURA <kazuki@ma.ccnw.ne.jp> 1.3-0vl1
- new upstream release

* Tue Nov 30 2004 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0-0vl1
- initial build for Vine Linux

* Tue Aug 31 2004 Bill Nottingham <notting@redhat.com> - 1.0-1
- update to 1.0

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Apr 16 2004 Bill Nottingham <notting@redhat.com> - 0.7-1
- adapt upstream specfile
